@@ -1,11 +1,8 @@
 package GraphViz2::Config;
 
 use strict;
-use utf8;
 use warnings;
-use warnings  qw(FATAL utf8);    # Fatalize encoding glitches.
-use open      qw(:std :utf8);    # Undeclared streams in UTF-8.
-use charnames qw(:full :short);  # Unneeded in v5.16.
+use warnings  qw(FATAL utf8); # Fatalize encoding glitches.
 
 use Config::Tiny;
 
@@ -38,7 +35,7 @@ has section =>
 	required => 0,
 );
 
-our $VERSION = '2.27';
+our $VERSION = '2.28';
 
 # -----------------------------------------------
 
