@@ -1,18 +1,15 @@
 package GraphViz2::Filer;
 
 use strict;
-use utf8;
 use warnings;
-use warnings  qw(FATAL utf8);    # Fatalize encoding glitches.
-use open      qw(:std :utf8);    # Undeclared streams in UTF-8.
-use charnames qw(:full :short);  # Unneeded in v5.16.
+use warnings  qw(FATAL utf8); # Fatalize encoding glitches.
 
 use File::Basename; # For basename().
 use File::Slurp;    # For read_file().
 
 use Moo;
 
-our $VERSION = '2.27';
+our $VERSION = '2.28';
 
 # ------------------------------------------------
 
