@@ -1,11 +1,8 @@
 package GraphViz2::Utils;
 
 use strict;
-use utf8;
 use warnings;
-use warnings  qw(FATAL utf8);    # Fatalize encoding glitches.
-use open      qw(:std :utf8);    # Undeclared streams in UTF-8.
-use charnames qw(:full :short);  # Unneeded in v5.16.
+use warnings  qw(FATAL utf8); # Fatalize encoding glitches.
 
 use Config;
 
@@ -32,7 +29,7 @@ has config =>
 	required => 0,
 );
 
-our $VERSION = '2.27';
+our $VERSION = '2.28';
 
 # ------------------------------------------------
 
